@@ -1,3 +1,5 @@
+import os
+
 from pydantic import BaseSettings, BaseModel
 
 
@@ -39,4 +41,6 @@ class Config(BaseSettings):
         env_nested_delimiter = "__"
 
 
-config = Config(_env_file=".secrets.env")
+config = Config(
+    _env_file=".secrets.env", _secrets_dir=os.environ.get("SECRETS_PATH", "/var/run")
+)
